@@ -21,8 +21,8 @@ test_that("fastMask produces correct results", {
   origStack <- raster::stack(poly)
 
   ## mask
-  newStack1 <- raster::stack(raster::mask(origStack, mask = shpDF))
-  newStack2 <- fastMask(x = origStack, y = shpDF)
+  newStack1 <- raster::stack(raster::mask(origStack, mask = shp))
+  newStack2 <- fastMask(x = origStack, y = shp)
   expect_equal(newStack1, newStack2)
 
   newStack1 <- mask(origStack[[2]], mask = shpDF)
@@ -42,51 +42,52 @@ test_that("fastMask produces correct results", {
   names(newStack3) <- names(newStack1)
   expect_equivalent(newStack1, newStack3)
   # Run same as above but with different internal pathway
-  if (requireNamespace("gdalUtils", quietly = TRUE)) {
-    suppressWarnings(gdalUtils::gdal_setInstallation())
+  hasGDAL <- findGDAL()
+  if (!isTRUE(hasGDAL))
+    skip("no GDAL installation found")
 
-    # if it doesn't find gdal installed
-    hasGDALInstalled <- !is.null(getOption("gdalUtils_gdalPath"))
+  # if it doesn't find gdal installed
+  hasGDALInstalled <- !is.null(getOption("gdalUtils_gdalPath"))
 
-    testthat::with_mock(
-      "raster::canProcessInMemory" = function(x, n) {
-        FALSE
-      },
-      "reproducible::isWindows" = function() {
-        TRUE
-      },
-      # The warning is "data type "LOG" is not available in GDAL -- not relevant here
-      {
-        if (hasGDALInstalled) {
-          mess <- capture_messages({
-            out <- fastMask(x = origStack[[2]], y = shpDF)
-          })
-          expect_true(any(grepl("GDAL because crs", mess)))
-        }
+  testthat::with_mock(
+    "raster::canProcessInMemory" = function(x, n) {
+      FALSE
+    },
+    "reproducible::isWindows" = function() {
+      TRUE
+    },
+    # The warning is "data type "LOG" is not available in GDAL -- not relevant here
+    {
+      if (hasGDALInstalled) {
+        mess <- capture_messages({
+          out <- fastMask(x = origStack[[2]], y = shpDF)
+        })
+        expect_true(any(grepl("GDAL because crs", mess)))
       }
-    )
+    }
+  )
+  mess <- capture_messages({
+    out <- fastMask(x = origStack[[2]], y = shpDF, cores = "none")
+  })
+  expect_true(any(grepl("useGDAL is TRUE, but problem is small enough for RA", mess)))
+
+  crs(shpDF) <- "+proj=lcc +lat_1=48 +lat_2=33 +lon_0=-100 +ellps=WGS84"
+  crs(shp) <- "+proj=lcc +lat_1=48 +lat_2=33 +lon_0=-100 +ellps=WGS84"
+  crs(origStack[[2]]) <- "+proj=lcc +lat_1=49 +lat_2=33 +lon_0=-100 +ellps=WGS84"
+
+  # Test "force" even for a small problem
+  warn <- capture_warnings({
     mess <- capture_messages({
-      out <- fastMask(x = origStack[[2]], y = shpDF, cores = "none")
+      out <- fastMask(x = origStack[[2]], y = shpDF, useGDAL = "force")
     })
-    expect_true(any(grepl("useGDAL is TRUE, but problem is small enough for RA", mess)))
+  })
+  expect_false(any(grepl("useGDAL is TRUE, but problem is small enough for RA", mess)))
 
-    crs(shpDF) <- "+proj=lcc +lat_1=48 +lat_2=33 +lon_0=-100 +ellps=WGS84"
-    crs(shp) <- "+proj=lcc +lat_1=48 +lat_2=33 +lon_0=-100 +ellps=WGS84"
-    crs(origStack[[2]]) <- "+proj=lcc +lat_1=49 +lat_2=33 +lon_0=-100 +ellps=WGS84"
+  newStack2 <- fastMask(x = origStack[[2]], y = shpDF)
 
-    # Test "force" even for a small problem
-    warn <- capture_warnings({
-      mess <- capture_messages({
-        out <- fastMask(x = origStack[[2]], y = shpDF, useGDAL = "force")
-      })
-    })
-    expect_false(any(grepl("useGDAL is TRUE, but problem is small enough for RA", mess)))
-
-    newStack2 <- fastMask(x = origStack[[2]], y = shpDF)
-
-    # test non-spatial polygons data frame
-    newStack2 <- fastMask(x = origStack[[2]], y = shp)
-}})
+  # test non-spatial polygons data frame
+  newStack2 <- fastMask(x = origStack[[2]], y = shp)
+})
 
 test_that("checkGDALVersion", {
   testInitOut <- testInit(needGoogle = FALSE, c("sp", "raster"))
